@@ -198,7 +198,7 @@ class StreamChatAsync(StreamChatInterface):
         params.update(
             {"filter_conditions": filter_conditions, "sort": self.normalize_sort(sort)}
         )
-        return await self.get("channels", params={"payload": json.dumps(params)})
+        return await self.post("channels", data=params)
 
     async def create_channel_type(self, data):
         if "commands" not in data or not data["commands"]:
@@ -483,7 +483,7 @@ class StreamChatAsync(StreamChatInterface):
         """
         Update a segment by id
         """
-        return await self.put(f"segments/{segment_id}", data=data)
+        return await self.put(f"segments/{segment_id}", data={"segment": data})
 
     async def delete_segment(self, segment_id):
         """
@@ -513,7 +513,7 @@ class StreamChatAsync(StreamChatInterface):
         """
         Update a campaign
         """
-        return await self.put(f"campaigns/{campaign_id}", data=data)
+        return await self.put(f"campaigns/{campaign_id}", data={"campaign": data})
 
     async def delete_campaign(self, campaign_id):
         """
